# project2

A basic project with Odoo addons in the root directory, and additional packages in the
`src` directory.

This layout is recommended when packaging existing addons repositories with addons at
the root.
